@@ -24,9 +24,27 @@ as.function.formula <- function(x, ...) {
 	}
 }
 
-match.funfn <- function(x, ...) UseMethod("match.funfn")
-match.funfn.default <- function(x, ...) base::match.fun(x, ...)
-match.funfn.formula <- as.function.formula
+match.funfn <- function(FUN, descend = TRUE) {
+    if (is.function(FUN)) 
+        return(FUN)
+	if (inherits(FUN, "formula"))
+		return(as.function.formula(FUN))
+    if (!(is.character(FUN) && length(FUN) == 1 || is.symbol(FUN))) {
+        FUN <- eval.parent(substitute(substitute(FUN)))
+        if (!is.symbol(FUN)) 
+            stop(gettextf("'%s' is not a function, character or symbol", 
+                deparse(FUN)), domain = NA)
+    }
+    envir <- parent.frame(2)
+    if (descend) 
+        FUN <- get(as.character(FUN), mode = "function", envir = envir)
+    else {
+        FUN <- get(as.character(FUN), mode = "any", envir = envir)
+        if (!is.function(FUN)) 
+            stop(gettextf("found non-function '%s'", FUN), domain = NA)
+    }
+    return(FUN)
+}
 
 fn <- structure(NA, class = "fn")
 "$.fn" <- function(x, FUN) {
