@@ -14,7 +14,7 @@ Lines <- "2006-01-24 02:41:24.00011,1.22930000,5,1.22950000,7
 # convert to chron
 to.chron <- function(x) 
    strapply(format(x), "([0-9-]+) ([0-9:]+)",
-	~ chron(as.Date(dd), tt), backref = -2,simplify = c)
+	~ chron(as.numeric(as.Date(dd)), tt), simplify = c)
 
 con <- textConnection(Lines)
 read.zoo(con, sep = ",", FUN = to.chron)
